==> crossfire-0.91.8.tar.gz: crossfire-0.91.8/include/includes.h <==
/*
 * static char *rcsid_includes_h =
 *   "$Id: includes.h,v 1.14 1994/12/30 06:37:53 master Exp $";
 */

/*
    CrossFire, A Multiplayer game for X-windows

    Copyright (C) 1994 Mark Wedel
    Copyright (C) 1992 Frank Tore Johansen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    The author can be reached via e-mail to master@rahul.net
*/

#ifndef INCLUDES_H
#define INCLUDES_H

#define ASSERT(x)
#if 0
#define ASSERT(x) if (!(x)) { kill(getpid(),11);}
#endif

#if defined(osf1) && !defined(__osf__)
#  define	__osf__
#endif

#if defined(sgi) && !defined(__sgi__)
#  define __sgi__
#endif

#ifdef sun
#  ifndef __sun__
#    define __sun__
#  endif
#endif

#if defined(ultrix) && !defined(__ultrix__)
#  define __ultrix__
#endif


#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <errno.h>
#include <signal.h>
#include <setjmp.h>
#include <fcntl.h>
#include <stdlib.h>

/* tempnam() is not declared ifdef __STRICT_ANSI__ or on NeXT's*/
#if defined(NeXT)
extern char *tempnam(char *dir, char *pfx);
#endif


#if defined(__sun__) && defined(SVR4)
#include <unistd.h>
#endif

#include <sys/types.h>
#include <sys/time.h>

#if defined(_IBMR2) 
#  include <time.h>
#  include <math.h> /* Ack!  Can anyone with IBM tell me what requires this? */
#endif

#ifndef sgi
#  include <sys/timeb.h>
#endif


#include <sys/stat.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include "config.h"
#include "define.h"
#include "logger.h"
#include "newclient.h"

#ifdef __osf__
#  include <unistd.h>
#  include "osf.h"
#endif

#ifdef __sgi__
#  include <unistd.h>
#  include <math.h>
#  include "sgi.h"
#endif

#ifdef linux
#  include <unistd.h>
#endif

#if defined (__sun__) && defined(StupidSunHeaders)
#  include "sunos.h"   /* Prototypes for standard libraries, sunos lack those */
#endif

#ifndef _Xconst /* In case it's older than X11R4 */
#define _Xconst const
#endif

#endif /* INCLUDES_H */

==> crossfire-0.93.2.tar.gz: crossfire-0.93.2/include/includes.h <==
/*
 * static char *rcsid_includes_h =
 *   "$Id: includes.h,v 1.19 1997/01/05 09:58:36 master Exp $";
 */

/*
    CrossFire, A Multiplayer game for X-windows

    Copyright (C) 1994 Mark Wedel
    Copyright (C) 1992 Frank Tore Johansen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    The author can be reached via e-mail to mark@pyramid.com
*/

#ifndef INCLUDES_H
#define INCLUDES_H

#define ASSERT(x)
#if 0
#define ASSERT(x) if (!(x)) { kill(getpid(),11);}
#endif

#if defined(osf1) && !defined(__osf__)
#  define	__osf__
#endif

#if defined(sgi) && !defined(__sgi__)
#  define __sgi__
#endif

#ifdef sun
#  ifndef __sun__
#    define __sun__
#  endif
#endif

#if defined(ultrix) && !defined(__ultrix__)
#  define __ultrix__
#endif


#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <errno.h>
#include <signal.h>
#include <setjmp.h>
#include <fcntl.h>
#include <stdlib.h>
#ifdef DMALLOC
#include <dmalloc.h>
#endif

/* tempnam() is not declared on NeXT's, linux with gcc -ansi */
#if defined(NeXT) || (defined(linux) && defined(__STRICT_ANSI__))
extern char *tempnam(char *dir, char *pfx);
#endif


#if defined(__sun__) && defined(SVR4)
#include <unistd.h>
#endif

#include <sys/types.h>
#include <sys/time.h>

#if defined(_IBMR2) 
#  include <time.h>
#  include <math.h> /* Ack!  Can anyone with IBM tell me what requires this? */
#endif

#ifndef sgi
#  include <sys/timeb.h>
#endif


#include <sys/stat.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include "config.h"
#include "define.h"
#include "logger.h"
#include "newclient.h"

#ifdef __osf__
#  include <unistd.h>
#  include "osf.h"
#endif

#ifdef __sgi__
#  include <unistd.h>
#  include <math.h>
#  include "sgi.h"
#endif

#ifdef linux
#  include <unistd.h>
#endif

#if defined (__sun__) && defined(StupidSunHeaders)
#  include "sunos.h"   /* Prototypes for standard libraries, sunos lack those */
#endif

#ifdef pyrSVR4
FILE *popen (const char *command, const char *type);
char *tempnam (const char *dir, const char *pfx);
#endif

#ifndef _Xconst /* In case it's older than X11R4 */
#define _Xconst const
#endif

#endif /* INCLUDES_H */
